==> Evergreen-ILS-3.15.8.tar.gz: Evergreen-ILS-3.15.8/Open-ILS/web/js/dojo/openils/opac/nls/de-de/opac.js <==
{
    ":BARCODE_PROMPT": "Barcode: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Abbrechen",
    ":SUBMIT_BUTTON_LABEL": "Absenden",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Antwort vom Passwortzur\u00fccksetzen",
    ":PWD_RESET_SUBMIT_SUCCESS": "Ihre Anfrage, den Passwortr\u00fccksetzungsprozess zu starten, wurde durchgef\u00fchrt. Wenn Ihr Zugang eine g\u00fcltige E-Mail-Adresse besitzt, sollten Sie eine E-Mail mit witerf\u00fchrenden Informationen zum R\u00fccksetzen Ihres Passworts erhalten.",
    ":PWD_RESET_SUBMIT_ERROR": "Das System konnte Ihre Anfrage nach Passwortr\u00fccksetzung nicht verarbeiten. Bitte versuchen Sie es erneut oder wenden sich an das Aufsichtspersonal mit der Bitte um Unterst\u00fctzung.",
    ":PWD_RESET_SUBMIT_STATUS": "Anfrage wird gesendet \u2026",
    ":PWD_RESET_FORGOT_PROMPT": "Passwort vergessen?",
    ":PWD_RESET_FORM_TITLE": "R\u00fccksetzen des Passwortes anfordern",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "MFHD-Eintrag hinzuf\u00fcgen",
    ":CREATED_MFHD_RECORD": "MFHD-Eintrag f\u00fcr ${0} wurde erstellt",
    ":DELETE_MFHD": "Eintrag l\u00f6schen",
    ":DELETE_MFHD_CONFIRM": "Sind Sie sicher, dass Sie diesen fortlaufenden Eintrag l\u00f6schen m\u00f6chten?",
    ":DELETED_MFHD_RECORD": "MFHD-Eintrag ${0} wurde gel\u00f6scht",
    ":EDIT_MFHD_RECORD": "Eintrag bearbeiten",
    ":EDIT_MFHD_MENU": "Best\u00e4nde bearbeiten",
    ":EDIT_PROPERTIES": "Eigenschaften \u00e4ndern",
    ":BASIC_HOLDINGS": "Inhalte",
    ":BASIC_HOLDINGS_ADD": "Zus\u00e4tzliche Inhaltsinformationen",
    ":INDEX_HOLDINGS": "Indizes",
    ":INDEX_HOLDINGS_ADD": "Zus\u00e4tzliche Indexinformation",
    ":CURRENT_HOLDINGS": "Aktueller Inhalt",
    ":CURRENT_INDEXES": "Aktuelle Indizes",
    ":CURRENT_SUPPLEMENTS": "Aktuelle Anh\u00e4nge",
    ":HOLDINGS_TABLE_CAPTION": "Bestandszusammenfassung (${0})",
    ":INCOMPLETE_VOLUMES": "Unvollst\u00e4ndige Inhalte",
    ":MISSING_VOLUMES": "Fehlende Inhalte",
    ":ONLINE_VOLUMES": "Online Inhalte",
    ":SAVE_MFHD_LABEL": "MFHD speichern",
    ":SUPPLEMENT_HOLDINGS": "Anh\u00e4nge",
    ":SUPPLEMENT_HOLDINGS_ADD": "Zus\u00e4tzliche erg\u00e4nzende Informationen",
    ":PLACE_HOLD": "Reservierung durchf\u00fchren",
    ":HOLD_STATUS_PLURAL": "Reservierung # ${0} von insgesamt ${1} Reservierungen und ${2} m\u00f6glichen Gegenst\u00e4nden",
    ":HOLD_STATUS_SINGULAR": "Reservierung # ${0} von insgesamt ${1} Reservierungen und ${2} m\u00f6glicher Gegenst\u00e4nd",
    ":MORE": "Mehr",
    ":MORE_COPIES_FULL_RECORD": "\u2026 f\u00fcr weitere Ausgaben siehe vollst\u00e4ndiger Eintrag",
    ":SOURCE_CANNOT_HAVE_COPIES": "Eintr\u00e4ge von ${0} k\u00f6nnen keine Kopien haben."
}

==> Evergreen-ILS-3.16.0.tar.gz: Evergreen-ILS-3.16.0/Open-ILS/web/js/dojo/openils/opac/nls/de-de/opac.js <==
{
    ":BARCODE_PROMPT": "Barcode: ",
    ":USERNAME_PROMPT": "Nutzername: ",
    ":CANCEL_BUTTON_LABEL": "Abbrechen",
    ":SUBMIT_BUTTON_LABEL": "Absenden",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Antwort vom Passwortzur\u00fccksetzen",
    ":PWD_RESET_SUBMIT_SUCCESS": "Ihre Anfrage, den Passwortr\u00fccksetzungsprozess zu starten, wurde durchgef\u00fchrt. Wenn Ihr Zugang eine g\u00fcltige E-Mail-Adresse besitzt, sollten Sie eine E-Mail mit witerf\u00fchrenden Informationen zum R\u00fccksetzen Ihres Passworts erhalten.",
    ":PWD_RESET_SUBMIT_ERROR": "Das System konnte Ihre Anfrage nach Passwortr\u00fccksetzung nicht verarbeiten. Bitte versuchen Sie es erneut oder wenden sich an das Aufsichtspersonal mit der Bitte um Unterst\u00fctzung.",
    ":PWD_RESET_SUBMIT_STATUS": "Anfrage wird gesendet \u2026",
    ":PWD_RESET_FORGOT_PROMPT": "Passwort vergessen?",
    ":PWD_RESET_FORM_TITLE": "R\u00fccksetzen des Passwortes anfordern",
    ":PWD_RESET_SUBMIT_PROMPT": "Um den Prozess des Passwortzur\u00fccksetzens zu starten, geben Sie entweder Ihren Barcode oder Ihren Nutzernamen in das Feld unten ein und klicken Sie \"Absenden\"",
    ":CREATE_MFHD": "MFHD-Eintrag hinzuf\u00fcgen",
    ":CREATED_MFHD_RECORD": "MFHD-Eintrag f\u00fcr ${0} wurde erstellt",
    ":DELETE_MFHD": "Eintrag l\u00f6schen",
    ":DELETE_MFHD_CONFIRM": "Sind Sie sicher, dass Sie diesen fortlaufenden Eintrag l\u00f6schen m\u00f6chten?",
    ":DELETED_MFHD_RECORD": "MFHD-Eintrag ${0} wurde gel\u00f6scht",
    ":EDIT_MFHD_RECORD": "Eintrag bearbeiten",
    ":EDIT_MFHD_MENU": "Best\u00e4nde bearbeiten",
    ":EDIT_PROPERTIES": "Eigenschaften \u00e4ndern",
    ":BASIC_HOLDINGS": "Inhalte",
    ":BASIC_HOLDINGS_ADD": "Zus\u00e4tzliche Inhaltsinformationen",
    ":INDEX_HOLDINGS": "Indizes",
    ":INDEX_HOLDINGS_ADD": "Zus\u00e4tzliche Indexinformation",
    ":CURRENT_HOLDINGS": "Aktueller Inhalt",
    ":CURRENT_INDEXES": "Aktuelle Indizes",
    ":CURRENT_SUPPLEMENTS": "Aktuelle Anh\u00e4nge",
    ":HOLDINGS_TABLE_CAPTION": "Bestandszusammenfassung (${0})",
    ":INCOMPLETE_VOLUMES": "Unvollst\u00e4ndige Inhalte",
    ":MISSING_VOLUMES": "Fehlende Inhalte",
    ":ONLINE_VOLUMES": "Online Inhalte",
    ":SAVE_MFHD_LABEL": "MFHD speichern",
    ":SUPPLEMENT_HOLDINGS": "Anh\u00e4nge",
    ":SUPPLEMENT_HOLDINGS_ADD": "Zus\u00e4tzliche erg\u00e4nzende Informationen",
    ":PLACE_HOLD": "Reservierung durchf\u00fchren",
    ":HOLD_STATUS_PLURAL": "Reservierung # ${0} von insgesamt ${1} Reservierungen und ${2} m\u00f6glichen Gegenst\u00e4nden",
    ":HOLD_STATUS_SINGULAR": "Reservierung # ${0} von insgesamt ${1} Reservierungen und ${2} m\u00f6glicher Gegenst\u00e4nd",
    ":MORE": "Mehr",
    ":MORE_COPIES_FULL_RECORD": "\u2026 f\u00fcr weitere Ausgaben siehe vollst\u00e4ndiger Eintrag",
    ":SOURCE_CANNOT_HAVE_COPIES": "Eintr\u00e4ge von ${0} k\u00f6nnen keine Kopien haben."
}
